{#- Hello-world dashboard resource — replaced by /plan + /build-next -#}
resources:
  dashboards:
    sample_dashboard:
      display_name: "[${bundle.target}] {{ demo_title }} — Sample"
      file_path: ../../src/dashboards/sample_dashboard.lvdash.json
      warehouse_id: ${var.warehouse_id}
      embed_credentials: true
      permissions:
        - level: CAN_RUN
          group_name: users
