{#- Hello-world bronze table — replaced by /plan + /build-next -#}
CREATE OR REFRESH STREAMING TABLE {{ catalog }}.default.bronze_customers
COMMENT "Sample bronze: raw customer data from landing zone"
TBLPROPERTIES ("quality" = "bronze")
AS SELECT
  *,
  current_timestamp() AS ingestion_timestamp
FROM STREAM read_files(
  "/Volumes/{{ catalog }}/default/landing/customers",
  format => "parquet",
  inferColumnTypes => true
);
